@@ -13,6 +13,11 @@ class BootstrapWidgetsTests(unittest.TestCase):
         html = bs_input_password('password')
         self.assertTrue('id="password"' in html)
 
+    def test_input_file(self):
+        html = bs_input_file('upload', value='x')
+        self.assertTrue('id="upload"' in html)
+        self.assertTrue('value=""' in html)
+
     def test_input_select(self):
         options = [{'label':'Option 1', 'value':'value1'}, {'label':'Option 2', 'value':'value2'}]
         html = bs_select_field('choices', options, selected_value='value2')
